#!/usr/bin/env python2
# -*- coding: utf-8 -*-

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

""" dkr (docker) module of flr """

from __future__ import absolute_import

import docker
import flr


def client_connect(client_args={}, registry=None, username=None):

    flr.log.info("Creating docker client connection.")
    dc = docker.Client(**client_args)

    if registry:
        # Note: This will require the login credentials to pre-exist in
        # the default path of ~/.dockercfg for the user this is running as
        #
        # FIXME - not sure if this is the best idea, maybe allow other auth
        #         configs?
        flr.log.info(
            "Logging into remote docker registry: {}".format(registry)
        )
        dc.login(username=username, registry=registry)

    return dc


def split_repo(repo_name):
    """
    Split a docker repo uri into it's reponame and tag

    :param repo_name: str, docker repo uri

    :return: tuple, (image_repo, image_tag)
    """

    try:
        image_repo, image_tag = repo_name.split(':')
    except ValueError:
        image_repo = repo_name
        image_tag = None

    return (image_repo, image_tag)


def remotecopy(src_image, dest_image, client_args={}, registry=None, username=None):
    """

    :param src_image: str, source docker image repo uri
    :param dest_image: str, source docker image repo uri
    :param client_args: dict, docker.Client args
    :param registry: str, registry uri to authenticate against
    """

    dc = client_connect(
        client_args=client_args,
        registry=registry,
        username=username
    )

    src_repo, src_tag = split_repo(src_image)
    dest_repo, dest_tag = split_repo(dest_image)

    flr.log.info("Pulling docker image: {}".format(src_image))
    dc.pull(src_repo, tag=src_tag)

    # We set 'force' here just as we would with 'docker tag' because often
    # times RelEng is updating an image in-place and we need to actively
    # overwrite the pre-existing base image for things like fedora:rawhide
    flr.log.info(
        "Tagging docker image {} with new tag {}".format(src_image, dest_image)
    )
    dc.tag(src_image, dest_repo, tag=dest_tag, force=True)

    flr.log.info(
        "Pushing newly tagged image {} to remote registry".format(
            dest_image
        )
    )
    dc.push(dest_image)

def removeimage(image_name):
    """

    :param image_name: str, name of docker image to remove
    """

    dc = client_connect()

    try:
        dc.remove_image(image_name)
        flr.log.info("Removed local image: {}".format(image_name))
    except Exception, e:
        flr.log.error("Unable to remove image: {}".format(image_name))
        flr.log.error(e)

# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
