#!/usr/bin/env python2
# -*- coding: utf-8 -*-

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

""" sigul module of flr """

import flr
import subprocess

# Base sigul command
SIGUL_CMD = "/usr/bin/sigul"

# sigul ENV
SIGUL_ENV = {}
SIGUL_ENV['NSS_HASH_ALG_SUPPORT'] = '+MD5'


def sign_rpm(key, src_path, dest_path):
    """
    Sign an rpm located at the provided key and path name using sigul

    :param key: str, the sigul signing key to be used
    :param src_path: str, the path to the rpm to be signed
    :param dest_path: str, the path to place
    """

    # Bash equivalent
    #
    # NSS_HASH_ALG_SUPPORT=+MD5 sigul sign-rpms \
    #       --v3-signature --store-in-koji fedora-24 \
    #       /mnt/koji/packages/openh264/1.5.2/0.3.git21e44bd.fc24/*/*rpm \
    #       -o tmp/signed/

    cmd = [
        SIGUL_CMD,
        "sign-rpms --v3-signature --store-in-koji",
        key,
        src_path,
        "-o {0}".format(dest_path)
    ]

    flr.log.info("Running command: {0}".format(' '.join(cmd)))
    subprocess.call(cmd, env=SIGUL_ENV)


def sign_repodata(key, repodata):
    """
    Sign repodata files

    :param key: str, the sigul signing key to be used
    :param repodata: list of str, list of paths to the repodata files
    """

    # Bash equiv
    #
    # for file in $(find f24-openh264-20151201/ -name repomd.xml); do
    #   NSS_HASH_ALG_SUPPORT=+MD5 sigul sign-data fedora-24 $file -o $file.asc
    # done

    for repomd in repodata:
        cmd = [
            SIGUL_CMD,
            "sign-data",
            key,
            repomd,
            "-o {0}.asc".format(repomd)
        ]

        flr.log.info("Running command: {0}".format(' '.join(cmd)))
        subprocess.call(cmd, env=SIGUL_ENV)


# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
